==> istio-model-v1beta1-6.3.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/ClientTLSSettingsFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface ClientTLSSettingsFluent<A extends ClientTLSSettingsFluent<A>> extends Fluent<A>{
  public String getCaCertificates();
  public A withCaCertificates(String caCertificates);
  public Boolean hasCaCertificates();
  public String getClientCertificate();
  public A withClientCertificate(String clientCertificate);
  public Boolean hasClientCertificate();
  public String getCredentialName();
  public A withCredentialName(String credentialName);
  public Boolean hasCredentialName();
  public Boolean getInsecureSkipVerify();
  public A withInsecureSkipVerify(Boolean insecureSkipVerify);
  public Boolean hasInsecureSkipVerify();
  public ClientTLSSettingsTLSmode getMode();
  public A withMode(ClientTLSSettingsTLSmode mode);
  public Boolean hasMode();
  public String getPrivateKey();
  public A withPrivateKey(String privateKey);
  public Boolean hasPrivateKey();
  public String getSni();
  public A withSni(String sni);
  public Boolean hasSni();
  public A addToSubjectAltNames(Integer index,String item);
  public A setToSubjectAltNames(Integer index,String item);
  public A addToSubjectAltNames(java.lang.String... items);
  public A addAllToSubjectAltNames(Collection<String> items);
  public A removeFromSubjectAltNames(java.lang.String... items);
  public A removeAllFromSubjectAltNames(Collection<String> items);
  public List<String> getSubjectAltNames();
  public String getSubjectAltName(Integer index);
  public String getFirstSubjectAltName();
  public String getLastSubjectAltName();
  public String getMatchingSubjectAltName(Predicate<String> predicate);
  public Boolean hasMatchingSubjectAltName(Predicate<String> predicate);
  public A withSubjectAltNames(List<String> subjectAltNames);
  public A withSubjectAltNames(java.lang.String... subjectAltNames);
  public Boolean hasSubjectAltNames();
  public A withInsecureSkipVerify();
  
}

==> istio-model-v1beta1-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1beta1/ClientTLSSettingsFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface ClientTLSSettingsFluent<A extends ClientTLSSettingsFluent<A>> extends Fluent<A>{
  public String getCaCertificates();
  public A withCaCertificates(String caCertificates);
  public Boolean hasCaCertificates();
  public String getClientCertificate();
  public A withClientCertificate(String clientCertificate);
  public Boolean hasClientCertificate();
  public String getCredentialName();
  public A withCredentialName(String credentialName);
  public Boolean hasCredentialName();
  public Boolean getInsecureSkipVerify();
  public A withInsecureSkipVerify(Boolean insecureSkipVerify);
  public Boolean hasInsecureSkipVerify();
  public ClientTLSSettingsTLSmode getMode();
  public A withMode(ClientTLSSettingsTLSmode mode);
  public Boolean hasMode();
  public String getPrivateKey();
  public A withPrivateKey(String privateKey);
  public Boolean hasPrivateKey();
  public String getSni();
  public A withSni(String sni);
  public Boolean hasSni();
  public A addToSubjectAltNames(int index,String item);
  public A setToSubjectAltNames(int index,String item);
  public A addToSubjectAltNames(java.lang.String... items);
  public A addAllToSubjectAltNames(Collection<String> items);
  public A removeFromSubjectAltNames(java.lang.String... items);
  public A removeAllFromSubjectAltNames(Collection<String> items);
  public List<String> getSubjectAltNames();
  public String getSubjectAltName(int index);
  public String getFirstSubjectAltName();
  public String getLastSubjectAltName();
  public String getMatchingSubjectAltName(Predicate<String> predicate);
  public Boolean hasMatchingSubjectAltName(Predicate<String> predicate);
  public A withSubjectAltNames(List<String> subjectAltNames);
  public A withSubjectAltNames(java.lang.String... subjectAltNames);
  public Boolean hasSubjectAltNames();
  public A withInsecureSkipVerify();
  
}
